#ifndef COLUMBUSDIALOGLOGGING_H
#define COLUMBUSDIALOGLOGGING_H

#include "widgets/ColumbusDialog.h"

class ColumbusDialogLoggingPrivate;

class ColumbusDialogLogging : public ColumbusDialog
{
    Q_OBJECT

public:
    explicit ColumbusDialogLogging(QWidget *parent = 0);
            ~ColumbusDialogLogging();

public slots:
    void setController(ApplicationController *controller);

protected slots:
    void setupUi();
    void updateUi();

    void loadConfig();
    void saveConfig();

private:
    ColumbusDialogLoggingPrivate *d;
};

#endif // COLUMBUSDIALOGLOGGING_H
